Crate dualhashkey

Crate dualhashkey 

An implementation of a 64-bit DualHashKey.

For use with hierarchical ordered collections, to quickly find subkeys and permit range queries.

Structs

DualHashKey
A key made of two hashes, whose raw value is never zero.

Constants

HIGH_MASK
A mask for the high-half of a DualHashKey.
HIGH_SHIFT
The offset of the high-half in a DualHashKey.
LOW_MASK
A mask for the low-half of a DualHashKey.
MAX
The highest possible DualHashKey.
MIN
The lowest possible DualHashKey.

Type Aliases

DHK
Shorthand alias for DualHashKey.
NonZeroU64
A u64 that is known not to equal zero.