An implementation of a 64-bit DualHashKey.
For use with hierarchical ordered collections, to quickly find subkeys and permit range queries.
Structs
- Dual
Hash Key - A key made of two hashes, whose raw value is never zero.
Constants
- HIGH_
MASK - A mask for the high-half of a DualHashKey.
- HIGH_
SHIFT - The offset of the high-half in a DualHashKey.
- LOW_
MASK - A mask for the low-half of a DualHashKey.
- MAX
- The highest possible DualHashKey.
- MIN
- The lowest possible DualHashKey.
Type Aliases
- DHK
- Shorthand alias for DualHashKey.
- NonZero
U64 - A
u64that is known not to equal zero.